<?php

namespace Drupal\bokbasen_checkout\ApiClient;

use Drupal\serialization\Encoder\JsonEncoder;

/**
 * Defines a common interface for Bokbasen Api Clients.
 */
interface BokbasenApiClientInterface {

  /**
   * Get base url for client.
   *
   * @return string
   *   Base endpoint url.
   */
  public function getBaseUrl();

  /**
   * Get audience value for the API.
   *
   * @return string
   *   Audience value.
   */
  public function getAudience();

  /**
   * Get credentials for a specific audience.
   *
   * @return array
   *   Credentials array(
   *      'client_id' => '...',
   *      'client_secret' => '...',
   *   ).
   */
  public function getCredentials();

  /**
   * Perform GET request.
   */
  public function getRequest(string $path, array $headers = [], string $encode_format = JsonEncoder::FORMAT);

  /**
   * Perform post json request.
   */
  public function jsonPostRequest(string $path, array $body, array $headers = [], string $encode_format = JsonEncoder::FORMAT);

  /**
   * Get login url.
   *
   * @return string
   *   Login URL.
   */
  public function getLoginUrl();

  /**
   * Check if test mode is enabled.
   *
   * @return bool
   *   Is test mode result.
   */
  public function isTestMode();

}
