<?php

namespace Drupal\bokbasen_checkout\ApiClient;

use Drupal\Core\Site\Settings;

/**
 * Bokskya API implementation.
 *
 * @link https://bokbasen.jira.com/wiki/spaces/api/pages/61964320/IDM
 */
class BokbasenBokskya extends BokbasenApiClientBase {

  /**
   * {@inheritdoc}
   */
  public function getBaseUrl() {
    return Settings::get('bokbasen_bokskya_api_url', 'https://api.bokbasen.io/bokskya');
  }

  /**
   * {@inheritdoc}
   */
  public function getAudience() {
    return Settings::get('bokbasen_bokskya_audience', 'https://api.bokbasen.io/bokskya/');
  }

  /**
   * {@inheritdoc}
   */
  public function getCredentials() {
    return Settings::get('bokbasen_bokskya_credentials', [
      'client_id' => '',
      'client_secret' => '',
    ]);
  }

  /**
   * Validate state for a Bokskya account by id or email.
   */
  public function validate(string $id) {
    $active = FALSE;
    $result = $this->getRequest(sprintf('/account/v1/%s', $id));
    if (isset($result['id']) && $result['active']) {
      return $result['id'];
    }

    return $active;
  }

  /**
   * Create a new DDS Bokskya user account.
   *
   * @param array $user_data
   *   User data array(
   *      'email' => 'example@mail.com',
   *      'name' => 'example_name',
   *      'surname' => 'example_surname')
   *
   * @return mixed
   *   User id or FALSE.
   */
  public function register(array $user_data) {
    $this->moduleHandler->alter('bokbasen_user_register', $user_data);
    $result = $this->jsonPostRequest('/account/v1', $user_data);
    if (isset($result['id'])) {
      return $result['id'];
    }

    return FALSE;
  }

  /**
   * Get personal bookshelf for DDS user in OPDS XML format.
   *
   * @link https://bokbasen.jira.com/wiki/spaces/api/pages/62685203/Bookshelf+OPDS#Get-OPDS
   *
   * @return array
   *   Entries.
   *   Entry = array(
   *    title => Product title,
   *    link => array(),
   *    author => array(name => Bob Hunter),
   *    id => 0a36837c-991b-4f10-99bb-a7caddeae52a,
   *    created => 2019-05-28T14:09:21.000Z,
   *    updated => 2010-03-04T14:03:16.000Z,
   *    dc:identifier => array(),
   *    dc:publisher => Universitetsforl.,
   *    dc:issued => 2010,
   *    dc:language => nob,
   *   )
   */
  public function getPersonalCatalog(string $ddsid) {
    $results = $this->getRequest(sprintf('/content/v1/%s', $ddsid), [], 'xml');
    if (!empty($results['entry'])) {
      // Check if only one.
      if (isset($results['entry']['id'])) {
        $results['entry'] = [
          $results['entry'],
        ];
      }
      return $results['entry'];
    }

    return [];
  }

}
