<?php

namespace Drupal\bokbasen_checkout\ApiClient;

use Drupal\Core\Site\Settings;
use GuzzleHttp\RequestOptions;

/**
 * Bokbasen metadata API implementation.
 */
class BokbasenMetadata extends BokbasenApiClientBase {

  const API_PATH_PREFIX = 'metadata';
  const DATE_FORMAT = 'YmdHis';

  /**
   * {@inheritdoc}
   */
  public function getBaseUrl() {
    return Settings::get('bokbasen_metadata_api_url', 'https://api.bokbasen.io');
  }

  /**
   * {@inheritdoc}
   */
  public function getAudience() {
    return Settings::get('bokbasen_metadata_audience', 'https://api.bokbasen.io/metadata/');
  }

  /**
   * {@inheritdoc}
   */
  public function getCredentials() {
    return Settings::get('bokbasen_metadata_credentials', [
      'client_id' => '',
      'client_secret' => '',
    ]);
  }

  /**
   * Export products.
   *
   * @link https://bokbasen.jira.com/wiki/spaces/api/pages/67993632/ONIX
   */
  public function onixProductsExport($page_size = 100, string $after = '', string $next = '', string $subscription = '', bool $decode = TRUE) {
    $credentials = $this->getCredentials();
    $token = $this->authenticator->getToken($credentials['client_id'], $credentials['client_secret'], $this->getAudience(), $this->getLoginUrl());
    $headers['Authorization'] = "Bearer {$token['access_token']}";

    $results = [];
    if (empty($subscription)) {
      $subscription = $this->getSubscriptionType();
    }
    if (!$after && !$next) {
      $after = $this->getAfterDate();
    }
    $query = sprintf('subscription=%s&pagesize=%s', $subscription, $page_size);
    if ($after && !$next) {
      $query .= sprintf('&after=%s', $after);
    }
    if (!$after && $next) {
      $query .= sprintf('&next=%s', $next);
    }
    $path = sprintf('/metadata/export/onix/v1?%s', $query);

    $response = $this->httpClient->request('GET', $this->getBaseUrl() . $path, [
      RequestOptions::HEADERS => $headers,
      RequestOptions::ALLOW_REDIRECTS => [
        'strict' => TRUE,
      ],
    ]);

    if ($response->getStatusCode() == 200) {
      $content = $response->getBody()->getContents();
      $results['results'] = $decode ? $this->xmlEncoder->decode($content, 'xml') : $content;
      if ($response->hasHeader('Link')) {
        $results['next'] = $response->getHeader('Next');
      }
    }
    else {
      $this->logger->error(sprintf('Something went wrong %s: %s. %s', $response->getStatusCode(), $response->getReasonPhrase(), $response->getBody()->getContents()));
    }

    return $results;
  }

  /**
   * Get subscription type.
   */
  public function getSubscriptionType() {
    return Settings::get('bokbasen_metadata_api_subscription', 'basic');
  }

  /**
   * Get after start date value.
   *
   * @return string
   *   Format yyyyMMddHHmmss.
   */
  public function getAfterDate() {
    return Settings::get('bokbasen_metadata_api_after_start', '20000109130000');
  }

}
